@@ -10,7 +10,7 @@ from enough.common.dotenough import DotEnoughOpenStack, DotEnoughLibvirt, Hosts
 from enough.common.host import host_factory
 from enough.common.service import service_factory
 from enough.common.openstack import OpenStack, Heat
-from enough.common.libvirt import Libvirt
+from enough.common.libvirt import Libvirt, libvirt_install
 from enough.common.ssh import SSH
 from enough.common import retry
 from enough.common import ansible_utils
@@ -122,7 +122,7 @@ class Enough(object):
                      '--exclude=group_vars/all/internal_network.yml',
                      f'{self.config_dir}/', f'{config_dir}/')
             all_dir = f'{config_dir}/inventory/group_vars/all'
-            open(f'{all_dir}/internal_network.yml', 'w').write(textwrap.dedent(f"""\
+            open(f'{all_dir}/internal_network.yml', 'w').write(textwrap.dedent("""\
             ---
             openstack_internal_network_prefix: "10.11.10"
             openstack_internal_network_cidr: "10.11.10.0/24"
@@ -226,7 +226,7 @@ class Enough(object):
 
     @staticmethod
     def volume_from_snapshot(snapshot):
-        return re.sub('^\d\d\d\d-\d\d-\d\d-', '', snapshot)
+        return re.sub(r'^\d\d\d\d-\d\d-\d\d-', '', snapshot)
 
     def host_from_snapshot(self, snapshot):
         volume_name = self.volume_from_snapshot(snapshot)
@@ -314,3 +314,7 @@ class Enough(object):
             self.openstack.volume_prune(self.args['days'])
         elif self.args.get('driver') == 'libvirt':
             self.libvirt.backup_prune(OpenStack(self.config_dir, **self.args))
+
+    def libvirt_install(self):
+        return libvirt_install(self.config_dir, self.share_dir,
+                               self.args['domain'], self.args['host'])
