@@ -125,7 +125,7 @@ class DotEnough(object):
     @staticmethod
     def _set_bind_service_group(services_pathname):
         if not os.path.exists(services_pathname):
-            open(services_pathname, 'w').write(textwrap.dedent(f"""\
+            open(services_pathname, 'w').write(textwrap.dedent("""\
             ---
             essential-service-group:
                hosts:
