@@ -12,6 +12,15 @@ from enough.common import retry
 log = logging.getLogger(__name__)
 
 
+def libvirt_install(config_dir, share_dir, domain, ip):
+    Hosts(config_dir).create_or_update('libvirt-hypervisor', ip, '22')
+    playbook = ansible_utils.Playbook(config_dir, share_dir)
+    playbook.run('--private-key', f'{config_dir}/infrastructure_key',
+                 '--limit', 'libvirt-hypervisor,localhost',
+                 f'{share_dir}/libvirt-hypervisor-playbook.yml')
+    return True
+
+
 class Libvirt(object):
 
     BIND_MAC = '52:54:00:00:00:02'
@@ -331,7 +340,7 @@ class Libvirt(object):
     def pets_get(self):
         return self.ansible.get_global_variable('libvirt_pets')
 
-    @retry.retry(sh.ErrorReturnCode_1, 1)
+    @retry.retry(sh.ErrorReturnCode_1, 13)
     def backup_create_pet_upload(self, openstack, pet):
         pathname = self.host_image_name(pet)
         log.info(f"backup upload {pathname} to {pet}")
