@@ -9,7 +9,8 @@ from enough.common.gitlab import GitLab
 testinfra_hosts = ['ansible://gitlab-host']
 
 
-def test_ci_runner(host, tmpdir):
+def test_ci_runner(request, host, tmpdir):
+    certs = request.session.infrastructure.certs()
     domain = host.run("hostname -d").stdout.strip()
     runner_host = testinfra.host.Host.get_host(
         'ansible://runner-host',
@@ -17,6 +18,7 @@ def test_ci_runner(host, tmpdir):
 
     urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
     gitlab = GitLab(f'https://lab.{domain}')
+    gitlab.certs(certs)
     gitlab.login('root', gitlab_utils.get_password())
     gitlab.recreate_project('root', 'testproject')
     runner_host.run("rm -f /tmp/*.out")
