@@ -8,7 +8,7 @@ IcingaHelper.icinga_host = 'bind-host'
 class TestChecks(IcingaHelper):
 
     def test_host(self):
-        assert 'jisti-host' in self.get_hosts(host='jisti-host')
+        assert 'jitsi-host' in self.get_hosts(host='jitsi-host')
 
     def test_service(self, host):
         assert self.is_service_ok('jitsi-host!Jitsi')
