@@ -1,4 +1,3 @@
-import time
 import testinfra
 
 from enough.common import retry
@@ -10,35 +9,27 @@ def test_sendmail(host):
     domain = host.run("hostname -d").stdout.strip()
 
     postfix_host = host
+    with postfix_host.sudo():
+        host.run("postsuper -d ALL")
+
     postfix_client_host = testinfra.host.Host.get_host(
         'ansible://bind-host',
         ansible_inventory=host.backend.ansible_inventory)
 
     cmd = postfix_client_host.run("""
-    ( echo 'To: loic+boundtofail@dachary.org' ; echo POSTFIX TEST ) |
+    ( echo 'To: loic+doomtofail@dachary.org' ; echo POSTFIX TEST ) |
     /usr/sbin/sendmail -v -F 'NO REPLY' -f 'noreply@{}' -t
     """.format(domain))
     print(cmd.stdout)
     print(cmd.stderr)
     assert 0 == cmd.rc
 
-    check = ("grep -q 'TLS connection established to postfix-host' "
-             "/var/log/syslog")
-    for _ in range(300):
-        print(check)
-        cmd = postfix_client_host.run(check)
-        if cmd.rc == 0:
-            break
-        time.sleep(1)
-
-    @retry.retry(AssertionError, tries=8)
+    @retry.retry(AssertionError, tries=5)
     def wait_for_mail():
         with postfix_host.sudo():
             cmd = host.run("""
-            ls /var/spool/postfix/hold
-            grep -q 'POSTFIX TEST' /var/spool/postfix/hold/*
+            grep -q doomtofail /var/spool/postfix/hold/*
             """)
-        print(cmd.stdout)
         assert cmd.rc == 0, f'{cmd.stdout} {cmd.stderr}'
     wait_for_mail()
 
