@@ -339,7 +339,7 @@ def test_volume_from_snapshot():
 def test_host_from_snapshot(tmpdir):
     e = create_enough(tmpdir, 'backup')
     host = 'sample-host'
-    snapshot = f'2010-07-08-sample-volume'
+    snapshot = '2010-07-08-sample-volume'
     assert e.host_from_snapshot(snapshot) == host
 
 
@@ -421,7 +421,7 @@ def test_info_internal(tmpdir):
     }))
     f = f'{config_dir}/inventory/services.yml'
     open(f, 'w').write(yaml.dump({
-        f'bind-service-group': {
+        'bind-service-group': {
             'hosts': {
                 'some-host': None,
             }
