@@ -4,6 +4,26 @@ import sh
 
 from enough.common import libvirt
 from enough.common.openstack import OpenStack
+from enough.common.dotenough import Hosts, DotEnoughLibvirt
+
+
+@pytest.mark.libvirt_integration
+def test_libvirt_install(dotenough_libvirt_fixture):
+    lv = libvirt.Libvirt(dotenough_libvirt_fixture.config_dir, '.',
+                         domain=dotenough_libvirt_fixture.domain)
+    info = lv.create_or_update([dotenough_libvirt_fixture.prefix])
+    assert info[dotenough_libvirt_fixture.prefix]['port'] == '22'
+    hypervisor_ip = info[dotenough_libvirt_fixture.prefix]['ipv4']
+    assert libvirt.libvirt_install(dotenough_libvirt_fixture.config_dir, '.',
+                                   dotenough_libvirt_fixture.domain,
+                                   hypervisor_ip) is True
+    hosts = Hosts(dotenough_libvirt_fixture.config_dir)
+    dotenough = DotEnoughLibvirt(dotenough_libvirt_fixture.config_dir,
+                                 dotenough_libvirt_fixture.domain)
+    assert hosts.get_ip('libvirt-hypervisor') == hypervisor_ip
+    assert sh.ssh('-oStrictHostKeyChecking=no',
+                  '-i', dotenough.private_key(), f'debian@{hypervisor_ip}',
+                  'which', 'virsh').exit_code == 0
 
 
 @pytest.mark.libvirt_integration
